import { useRoute } from 'vue-router';
import {
  AccountParams,
  DeptListItem,
  MenuParams,
  RoleParams,
  RolePageParams,
  MenuListGetResultModel,
  DeptListGetResultModel,
  AccountListGetResultModel,
  RolePageListGetResultModel,
  RoleListGetResultModel,
  DictParams,
  DictPageParams,
  DictAddParams,
  DictDataItem,
  DictRouteParams,
  DictPageListGetResultModel,
  DictListGetResultModel,
  DictRouteListGetResultModel,
  DictDataGetResultModel,
} from './model/systemModel';
import { defHttp } from '@/utils/http/axios';

enum Api {
  AccountList = '/system/user/list',
  deleteUserApi = '/system/user/deleteLogical/',
  IsAccountExist = '/system/accountExist',
  DeptList = '/system/dept/listAll',
  setRoleStatus = '/system/setRoleStatus',
  MenuList = '/system/getMenuList',
  RolePageList = '/system/getRoleListByPage',
  GetAllRoleList = '/system/role/listAll',
  // 创建字典查询接口
  DictPageList = '/system/dict/type/list',
  // 创建字典新增接口
  AddDict = '/system/dict/type/add',
  //创建字典修改接口
  updateDict = '/system/dict/type/update',
  //创建字典删除接口
  deleteDict = '/system/dict/type/deleteLogical/',
  //创建字典详情接口
  DictData = '/system/dict/data/list',
  //创建字典跳转后查询详情接口/dict/type/detail/
  DictRouteQuery = '/system/dict/type/detail/',
  //创建字典跳转后新增接口
  DictRouteAdd = '/system/dict/data/add',
  //创建字典跳转后修改接口
  DictRouteUpdate = '/system/dict/data/update',
  //创建字典跳转后删除接口
  DictRouteDelete = '/system/dict/data/deleteLogical/',
}

export const getAccountList = (params: AccountParams) =>
  defHttp.get<AccountListGetResultModel>({ url: Api.AccountList, params });

export const deleteUser = (params?: any) =>
  defHttp.delete<any>({ url: Api.deleteUserApi + params.id });

export const getDeptList = (params?: DeptListItem) =>
  defHttp.get<DeptListGetResultModel>({ url: Api.DeptList, params });

export const getMenuList = (params?: MenuParams) =>
  defHttp.get<MenuListGetResultModel>({ url: Api.MenuList, params });

export const getRoleListByPage = (params?: RolePageParams) =>
  defHttp.get<RolePageListGetResultModel>({ url: Api.RolePageList, params });

export const getAllRoleList = (params?: RoleParams) =>
  defHttp.get<RoleListGetResultModel>({ url: Api.GetAllRoleList, params });

export const setRoleStatus = (id: number, status: string) =>
  defHttp.post({ url: Api.setRoleStatus, params: { id, status } });

export const isAccountExist = (account: string) =>
  defHttp.post({ url: Api.IsAccountExist, params: { account } }, { errorMessageMode: 'none' });

//创建字典查询接口
export const getAllDictList = (params?: DictParams) =>
  defHttp.get<DictPageListGetResultModel>({ url: Api.DictPageList, params });
export const getDictListByPage = (params?: DictPageParams) =>
  defHttp.get<DictListGetResultModel>({ url: Api.DictPageList, params });
//创建字典跳转后查询详情接口/dict/type/detail/
export const getDict = (params?: any) => defHttp.get({ url: Api.DictRouteQuery + params });

//创建字典新增接口
export const addDict = (params?: DictAddParams) => defHttp.post({ url: Api.AddDict, params });
//创建字典修改接口
export const updateDict = (params?: DictAddParams) => defHttp.post({ url: Api.updateDict, params });
//创建字典删除接口
export const deleteDict = (params?: any) =>
  defHttp.delete<any>({ url: Api.deleteDict + params.id });
//创建字典详情接口
export const getDictData = (params?: DictParams) =>
  defHttp.get<DictListGetResultModel>({ url: Api.DictData, params });
//创建字典跳转后查询详情接口/dict/type/detail/
export const getDictQueryData = (params?: any) => defHttp.get({ url: Api.DictRouteQuery + params });
//创建字典数据新增接口
export const addDictData = (params?: any) => defHttp.post({ url: Api.DictRouteAdd, params });
//创建字典数据修改接口
export const upDateDictData = (params?: any) => defHttp.post({ url: Api.DictRouteUpdate, params });
//创建字典数据删除接口
export const deleteDictRoute = (params?: any) => defHttp.post({ url: Api.DictRouteDelete, params });
